#ifndef _COMPLEXFRACTAL_HPP_
#define _COMPLEXFRACTAL_HPP_

#include <complex>

/**
  * Interface f&uuml;r Fraktale in der komplexen Zahlenebene
  *
  * @author Sebastian Flothow, Marcell Dietl
  */
class ComplexFractal
{
public:
    /**
      * Berechnet den Wert f&uuml;r einen bestimmten Punkt.
      *
      * @param s Punkt in der komplexen Zahlenebene, f&uuml;r den die Berechnung durchgef&uuml;hrt werden soll.
      * @param precision Genauigkeit, mit der die einzelnen Pixel gerendert werden soll.
      * @param optimized Aktivieren des optimierten Escape-Time-Algorithmus.
      * @return Ergebnis der Berechnung, liegt im Intervall [0; 1].
      */
    virtual double calculate(const std::complex<double>& s, int precision, bool optimized) const = 0;

    /**
      * Virtueller Destruktor, damit delete f&uuml;r einen ComplexFractal-Pointer korrekt funktioniert
      */
    virtual ~ComplexFractal() {}
};

#endif // _COMPLEXFRACTAL_HPP_
