#include "complexfractalrenderer.hpp"

ComplexFractalRenderer::ComplexFractalRenderer(ComplexFractal* fractal, ColorMapper* mapper)
: fractal(fractal), mapper(mapper) {}

//
// Rendert das Fraktal anhand diverser in der Schnittstelle definierter Parameter. Die Werte
// von precision und optimized werden einfach an die Methode calculate() weitergereicht.
//
QImage ComplexFractalRenderer::render(std::complex<double> topLeft, double step, int precision, int width, int height, bool optimized) const
{
    QImage img(width, height, QImage::Format_RGB32);

    for (int x = 0; x < width; x++)
    {
        std::complex<double> t(topLeft);

        for (int y = 0; y < height; y++)
        {
            double val = fractal->calculate(t, precision, optimized);
            QRgb color = mapper->map(val);
            img.setPixel(x, y, color);

            t -= std::complex<double>(0, step);
        }

        topLeft += step;
    }

    return img;
}
