#ifndef _COMPLEXFRACTALRENDERER_HPP_
#define _COMPLEXFRACTALRENDERER_HPP_

#include <QImage>
#include <memory>

#include "complexfractal.hpp"
#include "colormapper.hpp"

/**
  * Berechnet ein Fraktal in der Ebene der komplexen Zahlen.
  *
  * @author Sebastian Flothow, Marcell Dietl
  */
class ComplexFractalRenderer
{
public:
    /**
      * Erzeugt einen ComplexFractalRenderer.
      *
      * @param fractal Fraktal, das gerendert werden soll. Der neue ComplexFractalRenderer wird Eigent&uuml;mer des ComplexFractal-Objekts.
      * @param mapper F&auml;rbung, die verwendet werden soll. Der neue ComplexFractalRenderer wird Eigent&uuml;mer des ColorMapper-Objekts.
      */
    ComplexFractalRenderer(ComplexFractal* fractal, ColorMapper* mapper);

    /**
      * Rendert das Fraktal.
      *
      * @param topLeft Komplexer Zahlenwert des oberen linken Pixels.
      * @param step Schrittweite entlang der realen bzw. imagin&auml;ren Achse pro Pixel.
      * @param precision Genauigkeit, mit der die einzelnen Pixel gerendert werden soll.
      * @param width Breite des zu rendernden Bildes in Pixeln.
      * @param height H&ouml;he des zu rendernden Bildes in Pixeln.
      * @param optimized Aktivieren des optimierten Escape-Time-Algorithmus.
      * @return Das gerenderte Fraktal.
      */
    QImage render(std::complex<double> topLeft = std::complex<double>(-2.0, 1.5), double step = 0.005, int precision = 50, int width = 800, int height = 600, bool optimized = false) const;
private:
    std::auto_ptr<ComplexFractal> fractal;
    std::auto_ptr<ColorMapper> mapper;
};

#endif // _COMPLEXFRACTALRENDERER_HPP_
