#ifndef _IMAGELABEL_HPP_
#define _IMAGELABEL_HPP_

#include <QObject>
#include <QLabel>
#include <QMouseEvent>
#include <complex>
#include <string>

/**
  * Label, das der Anzeige eines Fraktals dient.
  *
  * @author Marcell Dietl
  */
class ImageLabel : public QLabel
{
    Q_OBJECT
public:
    /**
      * Erzeugt ein ImageLabel.
      *
      * @param parent Setzen eines Eltern-Widgets.
      */
    ImageLabel(QWidget *parent = 0);

    /** Komplexer Zahlenwert des oberen linken Pixels des aktuell angezeigten Fraktals. */
    std::complex<double> topLeft;
    /** String-Repr&auml;sentierung des aktuell angezeigten Fraktals. */
    std::string name;
protected:
    /**
      * &Uuml;berschreiben der Methode, die beim Mausklick, ausgef&uuml;hrt wird.
      * Emittiert ein Signal mit den Koordinaten des angeklickten Pixels.
      *
      * @param event Das abgefangene Ereignis.
      */
    void mousePressEvent(QMouseEvent* event);
signals:
    /**
      * &Uuml;bertragen der Koordination eines Mausklicks im Fraktal.
      *
      * @param x Wert auf der realen Achse des angeklickten Pixels.
      * @param y Wert auf der imagin&auml;ren Achse des angeklickten Pixels.
      */
    void clicked(int x, int y);
};

#endif // _IMAGELABEL_HPP_
