#ifndef _MAINWINDOWIMPL_HPP_
#define _MAINWINDOWIMPL_HPP_

#include <QObject>
#include <QMessageBox>
#include <QFileDialog>

#include "mainwindow.hpp"
#include "controlwindow.hpp"
#include "controlwindowimpl.hpp"
#include "complexfractal.hpp"

/**
  * Implementierungen der Kn&ouml;pfe des Hauptfensters "Fraktale".
  *
  * @author Marcell Dietl
  */
class MainWindowImpl : public QObject
{
    Q_OBJECT
public:
    /**
      * Erzeugt die MainWindowImpl(ementation).
      *
      * @param mw Pointer auf das Hauptfenster "Fraktale".
      * @param cw Pointer auf das Fenster "Einstellungen".
      * @param cwi Pointer, um die Methode renderFractal() auszuf&uuml;hren.
      */
    MainWindowImpl(MainWindow* mw, ControlWindow* cw, ControlWindowImpl* cwi);
public slots:
    /** Speichern des angezeigten Fraktals mit niedriger Aufl&ouml;sung. */
    void saveAsLow();
    /** Speichern des angezeigten Fraktals mit mittlerer Aufl&ouml;sung. */
    void saveAsMedium();
    /** Speichern des angezeigten Fraktals mit hoher Aufl&ouml;sung. */
    void saveAsHigh();
    /** Zus&auml;tzliche Informationen zur Mandelbrot-Menge einblenden. */
    void mandelbrot();
    /** Zus&auml;tzliche Informationen zur Mandelbar-Menge einblenden. */
    void mandelbar();
    /** Zus&auml;tzliche Informationen zur Multibrot-Menge einblenden. */
    void multibrot();
    /** Zus&auml;tzliche Informationen zur Julia-Menge einblenden. */
    void julia();
    /** Informationen &uuml;ber den Autor und das Programm einblenden. */
    void about();
private:
    QString getFileName();
    ComplexFractal* getCurrentFractal();

    MainWindow* mw;
    ControlWindow* cw;
    ControlWindowImpl *cwi;

    QString fileName;
    QImage fractalImage;
    ComplexFractal* fractal;
};

#endif // _MAINWINDOWIMPL_HPP_
